import 'dart:developer';

import 'generic_list.dart';

class FieldsDetails {
    late String label;
    late String name;
    late FieldType displayType;
    late String valueType;
    late List<FieldsDetails?>? fields;
    late List<GenericList?>? options;
    late bool required;
    late String? value;
    late String? hintText;
    late String? suffixText;

    FieldsDetails({
        required this.label,
        required this.name,
        required this.displayType,
        required this.valueType,
        this.fields,
        this.options,
        required this.required,
        this.value,
        this.hintText,
        this.suffixText,
    });

    FieldsDetails.fromJson(dynamic input) {
        try {
            label = input['label'];
            name = input['name'];
            valueType = input['valueType'];
            fields =  input['fields'] != null ? [...input['fields'].map((e) => FieldsDetails.fromJson(e))] : null;
            options =  input['options'] != null ? [...input['options'].map((e) => GenericList.fromJson(e))] : null;
            required = input['required'];
            value = input['value'];
            hintText = input['hintText'];
            suffixText = input['suffixText'];

            for (int i = 0; i < FieldType.values.length; i ++) {
              if (FieldType.values[i].name == input['displayType']) {
                displayType = FieldType.values[i];
              }
            }
        } catch(e, stacktrace) {
            log(e.toString());
            log('Function: FieldsDetails.fromJson()');
            log(stacktrace.toString());
        }
    }
}

enum FieldType {
  text,
  textarea,
  phone,
  date,
  shortDate,
  number,
  zipCode,
  select,
  complex,
  amount,
}






